[![Build Status](https://travis-ci.org/crs4/pydoop.png)](https://travis-ci.org/crs4/pydoop)

[![Download Status](https://pypip.in/download/pydoop/badge.png)](https://pypi.python.org/pypi/pydoop)

Pydoop is a Python MapReduce and HDFS API for
[Hadoop](http://hadoop.apache.org/).

Copyright 2009-2015 [CRS4](http://www.crs4.it/).

To get started, take a look at [the docs](http://crs4.github.io/pydoop/).
